F2DOT14

Struct F2DOT14 

pub struct F2DOT14(/* private fields */);
The OpenType F2DOT14 type, a 2.14-bit signed fixed-point type.

Implementations

Source

impl F2DOT14

pub const STEP: Self

The difference between adjacent F2DOT14 values.

Examples
assert_eq!(F2DOT14::STEP, 0.000061035156);
pub const MIN: Self

The smallest value that can be represented by this type.

Examples
assert_eq!(F2DOT14::MIN, -2.0);
pub const MAX: Self

The largest value that can be represented by this type.

Examples
assert_eq!(F2DOT14::MAX, 1.999939);
pub const PRECISION: u32

The amount of decimal places the type can accurately represent.

Examples
assert_eq!(F2DOT14::PRECISION, 4);
pub const fn new(num: f32) -> Option<Self>

Creates a F2DOT14 from f32.

Examples
use ttf_view::types::F2DOT14;

assert_eq!(F2DOT14::new(-0.125).unwrap(), -0.125);
assert_eq!(F2DOT14::new(1.99609375).unwrap(), 1.99609375);
assert_eq!(F2DOT14::new(123456.78), None);

// numbers are rounded towards the closest value representable by F2DOT14
assert_eq!(F2DOT14::new(0.5156247).unwrap(), 0.515625);
assert_eq!(F2DOT14::new(0.5156250).unwrap(), 0.515625);
assert_eq!(F2DOT14::new(0.5156254).unwrap(), 0.515625);
pub const unsafe fn new_unchecked(num: f32) -> Self

Creates a F2DOT14 from f32 without checks.

TODO: # Examples

pub const fn from_be_bytes(bytes: [u8; 2]) -> Self

Creates a F2DOT14 from big-endian bytes.

TODO: # Examples

pub const fn to_be_bytes(self) -> [u8; 2]

Gets this F2DOT14’s big-endian bytes.

TODO: # Examples

pub const fn frac_num(&self) -> i16

Returns this F2DOT14 fraction’s numerator (F2DOT14 represented as numerator16384).

TODO: # Examples

pub const fn get(&self) -> f32

Returns this F2DOT14’s value as f32.

TODO: # Examples

pub const fn round_to_precision(&self) -> f32

Rounds this F2DOT14’s value to PRECISION decimal places.

TODO: # Examples