Version16Dot16

Struct Version16Dot16 

pub struct Version16Dot16(/* private fields */);
An OpenType Version16Dot16 version.

The upper 16 bits comprise a major version number, and the highest-order nibble (4 bits) of the lower 16 bits comprises a minor version number (0..=9 range). Simply put, the major version is in 0xFFFF0000, and the minor version is in 0x0000F000.

Implementations

Source

impl Version16Dot16

pub const V0_5: Self

Version 0.5.

pub const V1_0: Self

Version 1.0.

pub const fn new(major: u16, minor: u8) -> Option<Self>

Creates a Version16Dot16 from major and minor version numbers.

Examples
use ttf_view::types::Version16Dot16;

assert_eq!(Version16Dot16::new(0, 5).unwrap().tuple(), (0, 5));
assert_eq!(Version16Dot16::new(15, 9).unwrap().tuple(), (15, 9));
assert_eq!(Version16Dot16::new(0xFFFF, 9).unwrap().tuple(), (0xFFFF, 9));
assert_eq!(Version16Dot16::new(15, 10), None);
assert_eq!(Version16Dot16::new(1, 199), None);
pub const unsafe fn new_unchecked(major: u16, minor: u8) -> Self

Creates a Version16Dot16 from major and minor version numbers without checks.

Examples
use ttf_view::types::Version16Dot16;

assert_eq!(unsafe { Version16Dot16::new_unchecked(0, 5).tuple() }, (0, 5));
assert_eq!(unsafe { Version16Dot16::new_unchecked(0xFFFF, 9).tuple() }, (0xFFFF, 9));
pub const fn from_be_bytes(bytes: [u8; 4]) -> Option<Self>

Creates a Version16Dot16 from big-endian bytes.

Examples
use ttf_view::types::Version16Dot16;

assert_eq!(Version16Dot16::from_be_bytes([0x00, 0x00, 0x50, 0x00]).unwrap().tuple(), (0, 5));
assert_eq!(Version16Dot16::from_be_bytes([0x00, 0x01, 0x90, 0x00]).unwrap().tuple(), (1, 9));
assert_eq!(Version16Dot16::from_be_bytes([0x12, 0x34, 0x90, 0x00]).unwrap().tuple(), (0x1234, 9));
assert_eq!(Version16Dot16::from_be_bytes([0x00, 0x01, 0xA0, 0x00]), None);
assert_eq!(Version16Dot16::from_be_bytes([0x00, 0x01, 0x90, 0x64]), None);
pub const unsafe fn from_be_bytes_unchecked(bytes: [u8; 4]) -> Self

Creates a Version16Dot16 from big-endian bytes without checks.

Examples
use ttf_view::types::Version16Dot16;

assert_eq!(unsafe { Version16Dot16::from_be_bytes_unchecked([0x00, 0x00, 0x50, 0x00]).tuple() }, (0, 5));
assert_eq!(unsafe { Version16Dot16::from_be_bytes_unchecked([0x00, 0x01, 0x90, 0x00]).tuple() }, (1, 9));
assert_eq!(unsafe { Version16Dot16::from_be_bytes_unchecked([0x12, 0x34, 0x90, 0x00]).tuple() }, (0x1234, 9));
pub const fn to_be_bytes(self) -> [u8; 4]

Gets this Version16Dot16’s big-endian bytes.

Examples
use ttf_view::types::Version16Dot16;

assert_eq!(Version16Dot16::new(1, 5).unwrap().to_be_bytes(), [0x00, 0x01, 0x50, 0x00]);
assert_eq!(Version16Dot16::new(0x1234, 5).unwrap().to_be_bytes(), [0x12, 0x34, 0x50, 0x00]);
assert_eq!(Version16Dot16::new(0x1234, 9).unwrap().to_be_bytes(), [0x12, 0x34, 0x90, 0x00]);
pub const fn major(&self) -> u16

Gets this Version16Dot16’s major version number.

Examples
use ttf_view::types::Version16Dot16;

assert_eq!(Version16Dot16::new(0, 9).unwrap().major(), 0);
assert_eq!(Version16Dot16::new(13, 2).unwrap().major(), 13);
assert_eq!(Version16Dot16::new(0xFFFF, 5).unwrap().major(), 0xFFFF);
pub const fn minor(&self) -> u8

Gets this Version16Dot16’s minor version number.

Examples
use ttf_view::types::Version16Dot16;

assert_eq!(Version16Dot16::new(0, 9).unwrap().minor(), 9);
assert_eq!(Version16Dot16::new(13, 2).unwrap().minor(), 2);
assert_eq!(Version16Dot16::new(0xFFFF, 5).unwrap().minor(), 5);
pub const fn tuple(&self) -> (u16, u8)

Gets this Version16Dot16’s major and minor version numbers as a tuple.

Examples
use ttf_view::types::Version16Dot16;

assert_eq!(Version16Dot16::new(0, 9).unwrap().tuple(), (0, 9));
assert_eq!(Version16Dot16::new(13, 2).unwrap().tuple(), (13, 2));
assert_eq!(Version16Dot16::new(0xFFFF, 5).unwrap().tuple(), (0xFFFF, 5));