u24

Struct u24 

pub struct u24(/* private fields */);
The 24-bit unsigned integer type.

Important note: Despite only representing a valid range of a 24-bit unsigned integers, this type is actually backed by u32 to ensure it’s aligned well in the registers for efficient math, copies and pretty much all operations in general.

use ttf_view::types::{BigEndian, u24, uint24};

// u24 is backed by u32
assert_eq!(size_of::<u24>(), 4);

// big-endian types still have correct size (backed by [u8; 3])
assert_eq!(size_of::<uint24>(), 3);
assert_eq!(size_of::<BigEndian<u24>>(), 3);

Implementations

Source

impl u24

pub const BITS: u32 = 24

The size of this integer type in bits.

Examples
assert_eq!(u24::BITS, 24);
pub const MIN: Self

The smallest value that can be represented by this integer type.

Examples
assert_eq!(u24::MIN, 0);
pub const MAX: Self

The largest value that can be represented by this integer type (224 − 1).

Examples
assert_eq!(u24::MAX, 16_777_215);
pub const fn new(num: u32) -> Option<Self>

Creates a u24 from u32.

Examples
use ttf_view::types::u24;

assert_eq!(u24::new(1234).unwrap(), 1234);
assert_eq!(u24::new(15_000_000).unwrap(), 15_000_000);
assert_eq!(u24::new(0xFFFFFF).unwrap(), 0xFFFFFF);
assert_eq!(u24::new(17_000_000), None);
assert_eq!(u24::new(3_999_000_000), None);
pub const fn new_saturating(num: u32) -> Self

Creates a u24 from u32, saturating at the numeric bounds.

Examples
use ttf_view::types::u24;

assert_eq!(u24::new_saturating(1234), 1234);
assert_eq!(u24::new_saturating(15_000_000), 15_000_000);
assert_eq!(u24::new_saturating(0xFFFFFF), 0xFFFFFF);
assert_eq!(u24::new_saturating(17_000_000), 0xFFFFFF);
assert_eq!(u24::new_saturating(3_999_000_000), 0xFFFFFF);
pub const fn new_truncating(num: u32) -> Self

Creates a u24 from u32, truncating the most significant 8 bits.

Examples
use ttf_view::types::u24;

assert_eq!(u24::new_truncating(1234), 1234);
assert_eq!(u24::new_truncating(15_000_000), 15_000_000);
assert_eq!(u24::new_truncating(0xFFFFFF), 0xFFFFFF);
assert_eq!(u24::new_truncating(17_000_000), 222784);
assert_eq!(u24::new_truncating(3_999_000_000), 6022592);
pub const fn from_be_bytes(bytes: [u8; 3]) -> Self

Creates a u24 from big-endian bytes.

Examples
use ttf_view::types::u24;

assert_eq!(u24::from_be_bytes([0x00, 0x00, 0x07]), 7);
assert_eq!(u24::from_be_bytes([0x12, 0x34, 0x56]), 0x00123456);
pub const fn to_be_bytes(self) -> [u8; 3]

Gets this u24’s big-endian bytes.

Examples
use ttf_view::types::u24;

assert_eq!(u24::new(7).unwrap().to_be_bytes(), [0x00, 0x00, 0x07]);
assert_eq!(u24::new(0x00123456).unwrap().to_be_bytes(), [0x12, 0x34, 0x56]);
pub const fn get(self) -> u32

Gets the value of this u24 as u32.

Examples
use ttf_view::types::u24;

assert_eq!(u24::new(1234).unwrap(), 1234);
assert_eq!(u24::new(15_000_000).unwrap(), 15_000_000);
pub const fn wrapping_neg(self) -> Self

pub const fn wrapping_add(self, rhs: Self) -> Self

pub const fn wrapping_sub(self, rhs: Self) -> Self

pub const fn wrapping_mul(self, rhs: Self) -> Self

pub const fn wrapping_div(self, rhs: Self) -> Self

Panics

This function will panic if rhs == 0.

pub const fn wrapping_rem(self, rhs: Self) -> Self

Panics

This function will panic if rhs == 0.

pub const fn saturating_add(self, rhs: Self) -> Self

pub const fn saturating_sub(self, rhs: Self) -> Self

pub const fn saturating_mul(self, rhs: Self) -> Self

pub const fn saturating_div(self, rhs: Self) -> Self

Panics

This function will panic if rhs == 0.

pub const fn checked_neg(self) -> Option<Self>

pub const fn checked_add(self, rhs: Self) -> Option<Self>

pub const fn checked_sub(self, rhs: Self) -> Option<Self>

pub const fn checked_mul(self, rhs: Self) -> Option<Self>

pub const fn checked_div(self, rhs: Self) -> Option<Self>

pub const fn checked_rem(self, rhs: Self) -> Option<Self>