pub struct uint24(/* private fields */);Expand description
The 24-bit unsigned integer type stored in big-endian byte order.
Implementations
Sourceimpl uint24
impl uint24
Sourcepub const MIN: Self
pub const MIN: Self
The smallest value that can be represented by this integer type.
Examples
assert_eq!(uint24::MIN, 0);Sourcepub const MAX: Self
pub const MAX: Self
The largest value that can be represented by this integer type (224 − 1).
Examples
assert_eq!(uint24::MAX, 16_777_215);Sourcepub const fn new(num: u32) -> Option<Self>
pub const fn new(num: u32) -> Option<Self>
Creates a big-endian uint24 from u32.
Examples
use ttf_view::types::uint24;
assert_eq!(uint24::new(1234).unwrap(), 1234);
assert_eq!(uint24::new(15_000_000).unwrap(), 15_000_000);
assert_eq!(uint24::new(0xFFFFFF).unwrap(), 0xFFFFFF);
assert_eq!(uint24::new(17_000_000), None);
assert_eq!(uint24::new(3_999_000_000), None);Sourcepub const unsafe fn new_unchecked(num: u32) -> Self
pub const unsafe fn new_unchecked(num: u32) -> Self
Sourcepub const fn from_be_bytes(bytes: [u8; 3]) -> Self
pub const fn from_be_bytes(bytes: [u8; 3]) -> Self
Sourcepub const fn to_be_bytes(self) -> [u8; 3]
pub const fn to_be_bytes(self) -> [u8; 3]